from ft_package import flatten_list, reverse_string


def test_flatten_list():
    """test for function flatten_list"""
    assert flatten_list([[1, 2], [3, 4]]) == [1, 2, 3, 4]
    assert flatten_list([]) == []
    assert flatten_list([[1], [2, 3], [4]]) == [1, 2, 3, 4]


def test_reverse_string():
    """test for function reverse_string"""
    assert reverse_string("hello") == "olleh"
    assert reverse_string("") == ""
    assert reverse_string("Python") == "nohtyP"


test_flatten_list()
test_reverse_string()
print("All utility function tests passed!")



def flatten_list(nested_list):
    """Flattens a nested list."""
    return [item for sublist in nested_list for item in sublist]


def reverse_string(s):
    """Returns the reversed version of a string."""
    return s[::-1]



from ft_package import count_in_list


def test_count_in_list():
    """Test the function count_in_list"""
    assert count_in_list(["a", "b", "a"], "a") == 2
    assert count_in_list([1, 2, 3, 4, 4], 4) == 2
    assert count_in_list([], "a") == 0


test_count_in_list()
print("All test succeed!")



from setuptools import setup, find_packages


setup(
    name="jfatfat_package",
    version="0.0.3",
    author="Jihad Fatfat",
    author_email="jihadmohfatfat1999@gmail.com",
    description="A simple utility package",
    long_description=open("README.txt").read(),
    long_description_content_type="text/plain",
    url="https://github.com/jihadfatfat99/Python-Piscine/00/ex09/ft-package",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
